==> supercog-1.7.22.tar.gz: supercog-1.7.22/setup.py <==
from distutils.core import setup
setup(
  name = 'supercog',         # How you named your package folder (MyLib)
  packages = ['supercog'],   # Chose the same as "name"
  version = '1.7.22',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'A project that assists in making a Discord bot. Includes HTML and Markdown support.',   # Give a short description about your library
  author = 'FellowHashbrown',                   # Type in your name
  author_email = 'fellowhashbrown@gmail.com',      # Type in your E-Mail
  url = 'https://github.com/FellowHashbrown/supercog',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/FellowHashbrown/supercog/archive/v1.7.22.tar.gz',    # I explain this later on
  keywords = ["discord", "bot", "cogs", "extensions", "command", "category"],   # Keywords that define your package best
  install_requires=[

  ],
  classifiers=[
    'Development Status :: 4 - Beta',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
    'Programming Language :: Python :: 3.7',
  ],
)

==> supercog-1.8.tar.gz: supercog-1.8/setup.py <==
from distutils.core import setup
setup(
  name = 'supercog',         # How you named your package folder (MyLib)
  packages = ['supercog'],   # Chose the same as "name"
  version = '1.8',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'A project that assists in making a Discord bot. Includes HTML and Markdown support.',   # Give a short description about your library
  author = 'FellowHashbrown',                   # Type in your name
  author_email = 'fellowhashbrown@gmail.com',      # Type in your E-Mail
  url = 'https://github.com/FellowHashbrown/supercog',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/FellowHashbrown/supercog/archive/v1.8.tar.gz',    # I explain this later on
  keywords = ["discord", "bot", "cogs", "extensions", "command", "category"],   # Keywords that define your package best
  install_requires=[

  ],
  classifiers=[
    'Development Status :: 4 - Beta',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
    'Programming Language :: Python :: 3.7',
  ],
)
